#!/bin/sh

. ../../../prepare.inc.sh

# ------- boilerplate setup code ------
# ---- customize this where needed ----

OUTPUTFILE=`mktemp /mnt/testarea/tmp.XXXXXXXX`
PACKAGE=$(rpm -q --qf "%{name}" --whatprovides /bin/keyctl)

# source the test script helpers
. /usr/bin/rhts_environment.sh
. ../../../toolbox.inc.sh


# ---- do the actual testing ----

result=PASS
echo "++++ BEGINNING TEST" >$OUTPUTFILE

# check that show shows us our session keyring
marker "SHOW SESSION KEYRING"
keyctl show >>$OUTPUTFILE 2>&1
if [ $? != 0 ]
then
    failed
fi

# must be at least two lines in the output (plus the test banner lines)
nlines=`wc -l $OUTPUTFILE | cut -d\  -f1`
if [ "$nlines" -lt 4 ]
then
    failed
fi

# there must be a session keyring section on the third line
if [ "`sed -n -e 3p $OUTPUTFILE`" != "Session Keyring" ]
then
    failed
fi

# the first key listed (line 2) should be a keying (the session keyring) ...
keyring1="`grep -n keyring $OUTPUTFILE | cut -d: -f1 | head -1`"
if [ "$keyring1" != "4" ]
then
    failed
fi

# ... and it should be the session keyring (alias -3)
keyring1id="`sed -n -e 4p $OUTPUTFILE | awk '{print $1}'`"
if [ "$keyring1id" != "-3" ]
then
    failed
fi


echo "++++ FINISHED TEST: $result" >>$OUTPUTFILE

# --- then report the results in the database ---
toolbox_report_result $TEST $result
